==> zio-aws-iotfleetwise_2.13-6.20.103.1-sources.jar: zio/aws/iotfleetwise/model/GetModelManifestResponse.scala <==
package zio.aws.iotfleetwise.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iotfleetwise.model.primitives.{
  Timestamp,
  Description,
  Arn,
  ResourceName
}
import scala.jdk.CollectionConverters._
final case class GetModelManifestResponse(
    name: ResourceName,
    arn: Arn,
    description: Optional[Description] = Optional.Absent,
    signalCatalogArn: Optional[Arn] = Optional.Absent,
    status: Optional[zio.aws.iotfleetwise.model.ManifestStatus] =
      Optional.Absent,
    creationTime: Timestamp,
    lastModificationTime: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse = {
    import GetModelManifestResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
      .builder()
      .name(ResourceName.unwrap(name): java.lang.String)
      .arn(Arn.unwrap(arn): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        signalCatalogArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.signalCatalogArn)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .creationTime(Timestamp.unwrap(creationTime): Instant)
      .lastModificationTime(Timestamp.unwrap(lastModificationTime): Instant)
      .build()
  }
  def asReadOnly: zio.aws.iotfleetwise.model.GetModelManifestResponse.ReadOnly =
    zio.aws.iotfleetwise.model.GetModelManifestResponse.wrap(buildAwsValue())
}
object GetModelManifestResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotfleetwise.model.GetModelManifestResponse =
      zio.aws.iotfleetwise.model.GetModelManifestResponse(
        name,
        arn,
        description.map(value => value),
        signalCatalogArn.map(value => value),
        status.map(value => value),
        creationTime,
        lastModificationTime
      )
    def name: ResourceName
    def arn: Arn
    def description: Optional[Description]
    def signalCatalogArn: Optional[Arn]
    def status: Optional[zio.aws.iotfleetwise.model.ManifestStatus]
    def creationTime: Timestamp
    def lastModificationTime: Timestamp
    def getName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(name)
    def getArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(arn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getSignalCatalogArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("signalCatalogArn", signalCatalogArn)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.iotfleetwise.model.ManifestStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getLastModificationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastModificationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
  ) extends zio.aws.iotfleetwise.model.GetModelManifestResponse.ReadOnly {
    override val name: ResourceName =
      zio.aws.iotfleetwise.model.primitives.ResourceName(impl.name())
    override val arn: Arn =
      zio.aws.iotfleetwise.model.primitives.Arn(impl.arn())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotfleetwise.model.primitives.Description(value))
    override val signalCatalogArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.signalCatalogArn())
      .map(value => zio.aws.iotfleetwise.model.primitives.Arn(value))
    override val status: Optional[zio.aws.iotfleetwise.model.ManifestStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.iotfleetwise.model.ManifestStatus.wrap(value))
    override val creationTime: Timestamp =
      zio.aws.iotfleetwise.model.primitives.Timestamp(impl.creationTime())
    override val lastModificationTime: Timestamp =
      zio.aws.iotfleetwise.model.primitives
        .Timestamp(impl.lastModificationTime())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
  ): zio.aws.iotfleetwise.model.GetModelManifestResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iotfleetwise_3-7.21.15.9-sources.jar: zio/aws/iotfleetwise/model/GetModelManifestResponse.scala <==
package zio.aws.iotfleetwise.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iotfleetwise.model.primitives.{
  Timestamp,
  Description,
  Arn,
  ResourceName
}
import scala.jdk.CollectionConverters.*
final case class GetModelManifestResponse(
    name: ResourceName,
    arn: Arn,
    description: Optional[Description] = Optional.Absent,
    signalCatalogArn: Optional[Arn] = Optional.Absent,
    status: Optional[zio.aws.iotfleetwise.model.ManifestStatus] =
      Optional.Absent,
    creationTime: Timestamp,
    lastModificationTime: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse = {
    import GetModelManifestResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
      .builder()
      .name(ResourceName.unwrap(name): java.lang.String)
      .arn(Arn.unwrap(arn): java.lang.String)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        signalCatalogArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.signalCatalogArn)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .creationTime(Timestamp.unwrap(creationTime): Instant)
      .lastModificationTime(Timestamp.unwrap(lastModificationTime): Instant)
      .build()
  }
  def asReadOnly: zio.aws.iotfleetwise.model.GetModelManifestResponse.ReadOnly =
    zio.aws.iotfleetwise.model.GetModelManifestResponse.wrap(buildAwsValue())
}
object GetModelManifestResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotfleetwise.model.GetModelManifestResponse =
      zio.aws.iotfleetwise.model.GetModelManifestResponse(
        name,
        arn,
        description.map(value => value),
        signalCatalogArn.map(value => value),
        status.map(value => value),
        creationTime,
        lastModificationTime
      )
    def name: ResourceName
    def arn: Arn
    def description: Optional[Description]
    def signalCatalogArn: Optional[Arn]
    def status: Optional[zio.aws.iotfleetwise.model.ManifestStatus]
    def creationTime: Timestamp
    def lastModificationTime: Timestamp
    def getName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(name)
    def getArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(arn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getSignalCatalogArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("signalCatalogArn", signalCatalogArn)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.iotfleetwise.model.ManifestStatus] =
      AwsError.unwrapOptionField("status", status)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getLastModificationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastModificationTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
  ) extends zio.aws.iotfleetwise.model.GetModelManifestResponse.ReadOnly {
    override val name: ResourceName =
      zio.aws.iotfleetwise.model.primitives.ResourceName(impl.name())
    override val arn: Arn =
      zio.aws.iotfleetwise.model.primitives.Arn(impl.arn())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotfleetwise.model.primitives.Description(value))
    override val signalCatalogArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.signalCatalogArn())
      .map(value => zio.aws.iotfleetwise.model.primitives.Arn(value))
    override val status: Optional[zio.aws.iotfleetwise.model.ManifestStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.iotfleetwise.model.ManifestStatus.wrap(value))
    override val creationTime: Timestamp =
      zio.aws.iotfleetwise.model.primitives.Timestamp(impl.creationTime())
    override val lastModificationTime: Timestamp =
      zio.aws.iotfleetwise.model.primitives
        .Timestamp(impl.lastModificationTime())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotfleetwise.model.GetModelManifestResponse
  ): zio.aws.iotfleetwise.model.GetModelManifestResponse.ReadOnly = new Wrapper(
    impl
  )
}
